/*
 * Sonar PL/SQL Toad Plugin
 * Copyright (C) 2012 SonarSource
 * dev@sonar.codehaus.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.plsqltoad;

import org.sonar.api.profiles.RulesProfile;
import org.sonar.api.rules.ActiveRule;

public class PlSqlToadRuleHelper {

  private static final String CUSTOM_TOAD_RULE_KEY = "CustomToadCheck";
  private static final String CUSTOM_TOAD_RULE_KEY_PREFIX = CUSTOM_TOAD_RULE_KEY + "_";
  private static final String TOAD_RULE_ID_PARAMTER_KEY = "toadRuleID";

  private PlSqlToadRuleHelper() {
  }

  public static String getToadKey(ActiveRule activeRule) {
    String ruleKey = activeRule.getRuleKey();

    if (CUSTOM_TOAD_RULE_KEY.equals(ruleKey)) {
      return null;
    } else if (ruleKey.startsWith(CUSTOM_TOAD_RULE_KEY_PREFIX)) {
      return activeRule.getParameter(TOAD_RULE_ID_PARAMTER_KEY);
    } else {
      return ruleKey;
    }
  }

  public static ActiveRule getActiveRule(RulesProfile profile, String toadKey) {
    ActiveRule activeRule = profile.getActiveRule(PlSqlToadPlugin.KEY_REPOSITORY_TOAD, toadKey);
    if (activeRule == null) {
      activeRule = profile.getActiveRule(PlSqlToadPlugin.KEY_REPOSITORY_TOAD_11, toadKey);

      if (activeRule == null) {
        for (ActiveRule currentActiveRule : profile.getActiveRules()) {
          if (currentActiveRule.getRuleKey().startsWith(CUSTOM_TOAD_RULE_KEY_PREFIX) && toadKey.equals(currentActiveRule.getParameter(TOAD_RULE_ID_PARAMTER_KEY))) {
            activeRule = currentActiveRule;
          }
        }
      }
    }

    return activeRule;
  }

}
